<?php
/* 
Plugin Name: BigBarn Map
Plugin URI: https://www.bigbarn.co.uk/
Description: Easily display the BigBarn Local Food Map on your website.
Author: Pipe Media
Author URI: http://pipe.media
Version: 1.0

Copyright 2017 Pipe Media Design Limited
*/

add_shortcode('bigbarn_map', 'bigbarn_map');

function bigbarn_map($args){

	wp_enqueue_script( 'bb-map-js', 'https://d2kcsg7gwgf2xu.cloudfront.net/map.js' );

	$args =  shortcode_atts( array(
      'width' => 'width',
      'height' => 'height',
      'partner' => 'partner',
      'latitude' => 'latitude',
      'longitude' => 'longitude',
      'zoom' => 'zoom'
    ), $args, 'bigbarn_map' ) ;
    
	ob_start();

	$widget_html = '<div class = "bigbarn-map"';

	$width = esc_attr( get_option('BB_width'));
  	if(!empty($args['width']) && $args['width'] != 'width'){
  		$widget_html .= ' data-width="'.esc_attr( $args['width']).'" ';
  	}else if(!empty($width)){
		$widget_html .= ' data-width="'.esc_attr( get_option('BB_width')).'" ';
	}else{
		$widget_html .= ' data-width="940" ';
	}

	$height = esc_attr( get_option('BB_height'));
	if(!empty($args['height']) && $args['height'] != 'height'){
		$widget_html .= ' data-height="'.esc_attr( $args['height']).'" ';
	}else if(!empty($height)){
		$widget_html .= ' data-height="'.esc_attr( get_option('BB_height')).'" ';
	}else{
		$widget_html .= ' data-height="700" ';
	}

	$partner = esc_attr( get_option('BB_partner'));
	if(!empty($args['partner']) && $args['partner'] != 'partner'){
		$widget_html .= ' data-partner="'.esc_attr( $args['partner']).'" ';
	}else if(!empty($partner)){
		$widget_html .= ' data-partner="'.esc_attr( get_option('BB_partner')).'" ';
	}

	$latitude = esc_attr( get_option('BB_latitude'));
	if(!empty($args['latitude']) && $args['latitude'] != 'latitude'){
		$widget_html .= ' data-lat="'.esc_attr( $args['latitude']).'" ';
	} else if(!empty($latitude)){
		$widget_html .= ' data-lat="'.esc_attr( get_option('BB_latitude')).'" ';
	}

	$longitude = esc_attr( get_option('BB_longitude'));
	if(!empty($args['longitude']) && $args['longitude'] != 'longitude'){
		$widget_html .= ' data-lng="'.esc_attr( $args['longitude'] ).'" ';
	}else if(!empty($longitude)){
		$widget_html .= ' data-lng="'.esc_attr( get_option('BB_longitude')).'" ';
	}

	$zoom = esc_attr( get_option('BB_zoom'));
	if(!empty($args['zoom']) && $args['zoom'] != 'zoom'){
		$widget_html .= ' data-zoom="'.esc_attr( $args['zoom'] ).'" ';
	}elseif(!empty($zoom)){
		$widget_html .= ' data-zoom="'.esc_attr( get_option('BB_zoom')).'" ';
	}

	$widget_html .= '></div>';

	echo $widget_html;

	return ob_get_clean();
}

add_action( 'admin_menu', 'bigbarn_menu' );
add_action( 'admin_init', 'register_bigbarn_settings' );

function register_bigbarn_settings() {
	register_setting( "bb_general", "BB_latitude", array(
		'type' => 'string'
	));
	register_setting( "bb_general", "BB_longitude" , array(
		'type' => 'string'
	));
	register_setting( "bb_general", "BB_height" , array(
		'type' => 'string'
	));
	register_setting( "bb_general", "BB_width" , array(
		'type' => 'string'
	));
	register_setting( "bb_general", "BB_zoom" , array(
		'type' => 'string'
	));
	register_setting( "bb_general", "BB_partner" , array(
		'type' => 'string'
	));
}

function bigbarn_menu() {
	$page = add_options_page( 'BigBarn Map', 'BigBarn Map', 'manage_options', 'bigbarn-map', 'bigbarn_options' );
}

function bigbarn_options(){
	if ( !current_user_can( 'manage_options' ) )  {
		wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
	}
	echo '<div class = "wrap"><div id = "poststuff"><div id="post-body" class = "columns-2">';
	echo 	'<div id="post-body-content" style = "position: relative;">';
	echo 	'<h1>BigBarn</h1>';
	echo 	'<p>The map widget enables you to easily embed the BigBarn map on your website. Just like on the BigBarn website, your visitors can interact and browse the map without leaving your website.</p>';
	echo 	'<form method="post" action="options.php"> ';
			settings_fields( 'bb_general' );
			do_settings_sections( 'bb_general' );
	echo 	'<table class="form-table">';
	echo 		'<tr valign="top">';
	echo 			'<th colspan="2"><h3>Map Settings</h3><p class = "description">Leave fields blank if you do not want them applied. </p></th>';
	echo 		'</tr>';
	echo 		'<tr valign="top">';
	echo 			'<th scope = "row">Width</th>';
	echo 			'<td>
						<input id = "BB_width" class="regular-text ltr" placeholder="940" type="text" name="BB_width" value="'.esc_attr( get_option('BB_width') ).'" />
						<p class = "description">The width of the map. Will only be applied if the height is also set. </p>
					</td>';
	echo 		'</tr>';
	echo 		'<tr valign="top">';
	echo 			'<th scope = "row">Height</th>';
	echo 			'<td>
						<input id = "BB_height" class="regular-text ltr" type="text" placeholder="700" name="BB_height" value="'.esc_attr( get_option('BB_height') ).'" />
						<p class = "description">The height of the map. Will only be applied if the width is also set. </p>
					</td>';
	echo 		'</tr>';
	echo 		'<tr valign="top">';
	echo 			'<th scope = "row">Partner</th>';
	echo 			'<td>
						<input id = "BB_partner" class="regular-text ltr" type="text" placeholder="BFV4FqaYPq" name="BB_partner" value="'.esc_attr( get_option('BB_partner') ).'" />
						<p class = "description">If you are a BigBarn partner enter your partner key. </p>
					</td>';
	echo 		'</tr>';
	echo 		'<tr valign= "top">';
	echo 			'<th scope = "row">Latitude</th>';
	echo 			'<td>
						<input id = "BB_latitude" class = "regular-text ltr" type="text" placeholder="51.511218" name="BB_latitude" value="'.esc_attr( get_option('BB_latitude') ).'" />
						<p class = "description">The starting latitude of the map. Will only be applied if the longitude is also set. </p>
					</td>';
	echo 		'</tr>';
	echo 		'<tr valign="top">';
	echo 			'<th scope = "row">Longitude</th>';
	echo 			'<td>
						<input id = "BB_longitude" class="regular-text ltr" type="text"  placeholder="-0.140077" name="BB_longitude" value="'.esc_attr( get_option('BB_longitude') ).'" />
						<p class = "description">The starting longitude of the map. Will only be applied if the latitude is also set. </p>
					</td>';
	echo 		'</tr>';
	echo 		'<tr valign="top">';
	echo 			'<th scope = "row">Zoom</th>';
	echo 			'<td>
						<input id = "BB_zoom" class="regular-text ltr" type="text" placeholder="10"  name="BB_zoom" value="'.esc_attr( get_option('BB_zoom') ).'" />
						<p class = "description">
							The starting zoom level of the map. Will only be applied if the latitude and longitude are also set. The zoom attribute accepts a number between 1 and 20. 
							<br><br>
							The approximate detail you can expect to see at each zoom level is:
							<br><br>
							1: World
							<br>
							5: Landmass/Continent
							<br>
							10: City
							<br>
							15: Streets
							<br>
							20: Buildings
						</p>
					</td>';
	echo 		'</tr>';
	echo 	'</table>';
			submit_button();
	echo 	'</form>';
	echo '</div>';
	echo 	'<div id = "postbox-container-1" class="postbox-container">';
	echo 		'<div class = "postbox">';
	echo 			'<h2 class = "hndle">Shortcode</h2>';
	echo 			'<div class = "inside">';
	echo 				'<p>
							Add this shortcode to any page you wish to include the BigBarn Map.
							<br><br>
							[bigbarn_map]
						</p>';
	echo 			'</div>';
	echo 		'</div>';
	echo 		'<div class = "postbox">';
	echo 			'<h2 class = "hndle">For Advanced Users</h2>';
	echo 			'<div class = "inside">';
	echo 				'<p>
							Additional maps with custom options can be generated with the shortcode below. 
							<br><br>
							[bigbarn_map width="960" height="700"]
							<br><br>
							The list of usable attributes include: 
							<br><br>
							width<br>
							height<br>
							partner<br>
							latitude<br>
							longitude<br>
							zoom<br><br>
							Please note that the shortcode is space sensitive.
						</p>';
	echo 			'</div>';
	echo 		'</div>';
	echo 	'</div>';
	echo '</div></div></div>';
}

?>